@@ -22,7 +22,7 @@ use solana_poh::poh_recorder::WorkingBankEntry;
 use solana_runtime::bank::Bank;
 use solana_sdk::timing::timestamp;
 use solana_sdk::{clock::Slot, pubkey::Pubkey};
-use solana_streamer::{sendmmsg::send_mmsg, socket::is_global};
+use solana_streamer::{sendmmsg::send_mmsg, socket::SocketAddrSpace};
 use std::sync::atomic::AtomicU64;
 use std::{
     collections::HashMap,
@@ -386,6 +386,7 @@ pub fn broadcast_shreds(
     cluster_nodes: &ClusterNodes<BroadcastStage>,
     last_datapoint_submit: &Arc<AtomicU64>,
     transmit_stats: &mut TransmitShredsStats,
+    socket_addr_space: &SocketAddrSpace,
 ) -> Result<()> {
     let broadcast_len = cluster_nodes.num_peers();
     if broadcast_len == 0 {
@@ -397,7 +398,7 @@ pub fn broadcast_shreds(
         .iter()
         .filter_map(|shred| {
             let node = cluster_nodes.get_broadcast_peer(shred.seed())?;
-            if is_global(&node.tvu) {
+            if socket_addr_space.check(&node.tvu) {
                 Some((&shred.payload, &node.tvu))
             } else {
                 None
@@ -585,7 +586,11 @@ pub mod test {
         let broadcast_buddy = Node::new_localhost_with_pubkey(&buddy_keypair.pubkey());
 
         // Fill the cluster_info with the buddy's info
-        let cluster_info = ClusterInfo::new_with_invalid_keypair(leader_info.info.clone());
+        let cluster_info = ClusterInfo::new(
+            leader_info.info.clone(),
+            Arc::new(Keypair::new()),
+            SocketAddrSpace::Unspecified,
+        );
         cluster_info.insert_info(broadcast_buddy.info);
         let cluster_info = Arc::new(cluster_info);
 
